import Vue from "vue";
import VueI18n from 'vue-i18n'

import en from './en.json'
import zh from './zh.json'

Vue.use(VueI18n);   // 全局注册国际化包
 
// 准备翻译的语言环境信息
const i18n = new VueI18n({
  locale: "zh-cn",   // 初始化中文
  messages: {
    'en-us': en,
    'zh-cn': zh,
  }
}); 
 
export default i18n


// 非 vue 文件中使用这个方法可以使用多语言
const translate = (localeKey) => {
    const locale = uni.getStorageSync('language') || "zh-cn"
    const hasKey = i18n.te(localeKey, locale)  // 使用i18n的 te 方法来检查是否能够匹配到对应键值
    const translatedStr = i18n.t(localeKey) 
    if (hasKey) {
        return translatedStr
    }
    return localeKey
}
export { translate }
